BandSox

## Active Sandboxes

0

| ID | Resources | Status | Actions
--- | --- | --- | --- | ---

No active sandboxes found.

## Snapshots

0

| Name | Path | Actions
--- | --- | --- | ---

No snapshots available.

### Create Snapshot

Enter a name for this snapshot to save the current state.

Name
Metadata (optional JSON)

### Restore Snapshot

Create a new VM from this snapshot. Resources will match to snapshot state.

New VM Name

### Rename VM

Change the display name of this VM.

VM ID

New Name

## Edit Snapshot

Change the name or edit metadata

Snapshot ID

Snapshot Name
Metadata

### Confirm Action

Are you sure you want to proceed?